@@ -77,16 +77,17 @@ struct _ArvCameraPrivate {
 /**
  * arv_camera_create_stream:
  * @camera: a #ArvCamera
- * @callback: a frame processing callback
- * @user_data: closure
- * Return value: a new #ArvStream.
+ * @callback: (scope call) (allow-none): a frame processing callback
+ * @user_data: (closure) (allow-none): user data for @callback
  *
  * Creates a new #ArvStream for video stream handling. See
- * @arv_device_create_stream for details regarding the callback function.
+ * #ArvStreamCallback for details regarding the callback function.
+ *
+ * Returns: (transfer full): a new #ArvStream.
  */
 
 ArvStream *
-arv_camera_create_stream (ArvCamera *camera, ArvStreamCallback callback, void *user_data)
+arv_camera_create_stream (ArvCamera *camera, ArvStreamCallback callback, gpointer user_data)
 {
 	g_return_val_if_fail (ARV_IS_CAMERA (camera), NULL);
 
@@ -98,7 +99,8 @@ arv_camera_create_stream (ArvCamera *camera, ArvStreamCallback callback, void *u
 /**
  * arv_camera_get_vendor_name:
  * @camera: a #ArvCamera
- * Return value: the camera vendor name.
+ *
+ * Returns: the camera vendor name.
  */
 
 const char *
@@ -112,7 +114,8 @@ arv_camera_get_vendor_name (ArvCamera *camera)
 /**
  * arv_camera_get_model_name:
  * @camera: a #ArvCamera
- * Return value: the camera model name.
+ *
+ * Returns: the camera model name.
  */
 
 const char *
@@ -126,7 +129,8 @@ arv_camera_get_model_name (ArvCamera *camera)
 /**
  * arv_camera_get_device_id:
  * @camera: a #ArvCamera
- * Return value: the camera device ID.
+ *
+ * Returns: the camera device ID.
  */
 
 const char *
@@ -142,8 +146,8 @@ arv_camera_get_device_id (ArvCamera *camera)
 /**
  * arv_camera_get_sensor_size:
  * @camera: a #ArvCamera
- * @width: camera sensor width placeholder
- * @height: camera sensor height placeholder
+ * @width: (out): camera sensor width
+ * @height: (out): camera sensor height
  */
 
 void
@@ -187,10 +191,10 @@ arv_camera_set_region (ArvCamera *camera, gint x, gint y, gint width, gint heigh
 /**
  * arv_camera_get_region:
  * @camera: a #ArvCamera
- * @x: x offset placeholder
- * @y: y_offset placeholder
- * @width: region width placeholder
- * @height: region height placeholder
+ * @x: (out): x offset
+ * @y: (out): y_offset
+ * @width: (out): region width
+ * @height: (out): region height
  *
  * Retrieves the current region of interest.
  */
@@ -210,6 +214,15 @@ arv_camera_get_region (ArvCamera *camera, gint *x, gint *y, gint *width, gint *h
 		*height = arv_device_get_integer_feature_value (camera->priv->device, "Height");
 }
 
+/**
+ * arv_camera_get_width_bounds:
+ * @camera: a #ArvCamera
+ * @min: (out): minimum width
+ * @max: (out): maximum width
+ *
+ * Retrieves the valid range for image width.
+ */
+
 void
 arv_camera_get_width_bounds (ArvCamera *camera, gint *min, gint *max)
 {
@@ -225,6 +238,15 @@ arv_camera_get_width_bounds (ArvCamera *camera, gint *min, gint *max)
 		*max = max64;
 }
 
+/**
+ * arv_camera_get_height_bounds:
+ * @camera: a #ArvCamera
+ * @min: (out): minimum height
+ * @max: (out): maximum height
+ *
+ * Retrieves the valid range for image height.
+ */
+
 void
 arv_camera_get_height_bounds (ArvCamera *camera, gint *min, gint *max)
 {
@@ -246,7 +268,7 @@ arv_camera_get_height_bounds (ArvCamera *camera, gint *min, gint *max)
  * @dx: horizontal binning
  * @dy: vertical binning
  *
- * Defines the binning in both directions. Not all cameras support this
+ * Defines binning in both directions. Not all cameras support this
  * feature.
  */
 
@@ -264,10 +286,10 @@ arv_camera_set_binning (ArvCamera *camera, gint dx, gint dy)
 /**
  * arv_camera_get_binning:
  * @camera: a #ArvCamera
- * @dx: horizontal binning placeholder
- * @dy: vertical binning placeholder
+ * @dx: (out): horizontal binning placeholder
+ * @dy: (out): vertical binning placeholder
  *
- * Retrieves the binning in both directions.
+ * Retrieves binning in both directions.
  */
 
 void
@@ -286,7 +308,7 @@ arv_camera_get_binning (ArvCamera *camera, gint *dx, gint *dy)
  * @camera: a #ArvCamera
  * @format: pixel format
  *
- * Defines the pixel format.
+ * Defines pixel format.
  */
 
 void
@@ -301,7 +323,7 @@ arv_camera_set_pixel_format (ArvCamera *camera, ArvPixelFormat format)
  * arv_camera_get_pixel_format:
  * @camera: a #ArvCamera
  *
- * Retrieves the pixel format.
+ * Returns: pixel format.
  */
 
 ArvPixelFormat
@@ -312,6 +334,16 @@ arv_camera_get_pixel_format (ArvCamera *camera)
 	return arv_device_get_integer_feature_value (camera->priv->device, "PixelFormat");
 }
 
+/**
+ * arv_camera_get_available_pixel_formats:
+ * @camera: a #ArvCamera
+ * @n_pixel_formats: (out): number of different pixel formats
+ *
+ * Retrieves the list of all available pixel formats.
+ *
+ * Returns: (array length=n_pixel_formats) (transfer full): a newly allocated array of #ArvPixelFormat
+ */
+
 ArvPixelFormat *
 arv_camera_get_available_pixel_formats (ArvCamera *camera, guint *n_pixel_formats)
 {
@@ -345,7 +377,7 @@ arv_camera_get_available_pixel_formats (ArvCamera *camera, guint *n_pixel_format
  * arv_camera_start_acquisition:
  * @camera: a #ArvCamera
  *
- * Starts the video stream acquisition.
+ * Starts video stream acquisition.
  */
 
 void
@@ -360,7 +392,7 @@ arv_camera_start_acquisition (ArvCamera *camera)
  * arv_camera_stop_acquisition:
  * @camera: a #ArvCamera
  *
- * Stops the video stream acquisition.
+ * Stops video stream acquisition.
  */
 
 void
@@ -376,7 +408,7 @@ arv_camera_stop_acquisition (ArvCamera *camera)
  * @camera: a #ArvCamera
  * @acquisition_mode: acquisition mode
  *
- * Defines the acquisition mode.
+ * Defines acquisition mode.
  */
 
 void
@@ -391,9 +423,8 @@ arv_camera_set_acquisition_mode (ArvCamera *camera, ArvAcquisitionMode acquisiti
 /**
  * arv_camera_get_acquisition_mode:
  * @camera: a #ArvCamera
- * Return value: the acquisition mode.
  *
- * Retrieves the acquisition mode.
+ * Returns: acquisition mode.
  */
 
 ArvAcquisitionMode
@@ -430,6 +461,9 @@ arv_camera_set_frame_rate (ArvCamera *camera, double frame_rate)
 			arv_device_set_string_feature_value (camera->priv->device, "TriggerSelector",
 							     "AcquisitionStart");
 			arv_device_set_string_feature_value (camera->priv->device, "TriggerMode", "Off");
+			arv_device_set_string_feature_value (camera->priv->device, "TriggerSelector",
+							     "FrameStart");
+			arv_device_set_string_feature_value (camera->priv->device, "TriggerMode", "Off");
 			arv_device_set_integer_feature_value (camera->priv->device, "AcquisitionFrameRateEnable",
 							      1);
 			arv_device_set_float_feature_value (camera->priv->device, "AcquisitionFrameRateAbs",
@@ -454,7 +488,8 @@ arv_camera_set_frame_rate (ArvCamera *camera, double frame_rate)
 /**
  * arv_camera_get_frame_rate:
  * @camera: a #ArvCamera
- * Return value: the actual frame rate, in Hz.
+ *
+ * Returns: actual frame rate, in Hz.
  */
 
 double
@@ -478,9 +513,12 @@ arv_camera_get_frame_rate (ArvCamera *camera)
  * @source: trigger source as string
  *
  * Configures the camera in trigger mode. Typical values for source are "Line1"
- * or "Line2". See the camera documentation for the allowed values. The
- * activation is set to rising edge. It can be changed by accessing the
+ * or "Line2". See the camera documentation for the allowed values.
+ * Activation is set to rising edge. It can be changed by accessing the
  * underlying device object.
+ *
+ * Source can also be "Software". In this case, an acquisition is triggered
+ * by a call to @arv_camera_software_trigger.
  */
 
 void
@@ -493,28 +531,12 @@ arv_camera_set_trigger (ArvCamera *camera, const char *source)
 		case ARV_CAMERA_VENDOR_BASLER:
 			arv_device_set_integer_feature_value (camera->priv->device, "AcquisitionFrameRateEnable",
 							      0);
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerSelector",
-							     "AcquisitionStart");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerMode", "On");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerActivation",
-							     "RisingEdge");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerSource", source);
-			break;
-		case ARV_CAMERA_VENDOR_PROSILICA:
+		default:
 			arv_device_set_string_feature_value (camera->priv->device, "TriggerSelector",
 							     "AcquisitionStart");
 			arv_device_set_string_feature_value (camera->priv->device, "TriggerMode", "Off");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerSelector", "FrameStart");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerMode", "On");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerActivation",
-							     "RisingEdge");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerSource", source);
-			break;
-		case ARV_CAMERA_VENDOR_UNKNOWN:
 			arv_device_set_string_feature_value (camera->priv->device, "TriggerSelector",
-							     "AcquisitionStart");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerMode", "Off");
-			arv_device_set_string_feature_value (camera->priv->device, "TriggerSelector", "FrameStart");
+							     "FrameStart");
 			arv_device_set_string_feature_value (camera->priv->device, "TriggerMode", "On");
 			arv_device_set_string_feature_value (camera->priv->device, "TriggerActivation",
 							     "RisingEdge");
@@ -523,12 +545,28 @@ arv_camera_set_trigger (ArvCamera *camera, const char *source)
 	}
 }
 
+/**
+ * arv_camera_software_trigger:
+ * @camera: a #ArvCamera
+ *
+ * Sends a software trigger command to @camera. The camera must be previously
+ * configured to use a software trigger, using @arv_camera_set_trigger.
+ */
+
+void
+arv_camera_software_trigger (ArvCamera *camera)
+{
+	g_return_if_fail (ARV_IS_CAMERA (camera));
+
+	arv_device_execute_command (camera->priv->device, "TriggerSoftware");
+}
+
 /**
  * arv_camera_set_exposure_time:
  * @camera: a #ArvCamera
  * @exposure_time_us: exposure time, in µs
  *
- * Sets the exposure time. User should take care to set a value compatible with
+ * Sets exposure time. User should take care to set a value compatible with
  * the desired frame rate.
  */
 
@@ -556,7 +594,8 @@ arv_camera_set_exposure_time (ArvCamera *camera, double exposure_time_us)
 /**
  * arv_camera_get_exposure_time:
  * @camera: a #ArvCamera
- * Return value: the current exposure time, in µs.
+ *
+ * Returns: current exposure time, in µs.
  */
 
 double
@@ -567,6 +606,15 @@ arv_camera_get_exposure_time (ArvCamera *camera)
 	return arv_device_get_float_feature_value (camera->priv->device, "ExposureTimeAbs");
 }
 
+/**
+ * arv_camera_get_exposure_time_bounds:
+ * @camera: a #ArvCamera
+ * @min: (out): minimum exposure time
+ * @max: (out): maximum exposure time
+ *
+ * Retrieves exposure time bounds, in µs.
+ */
+
 void
 arv_camera_get_exposure_time_bounds (ArvCamera *camera, double *min, double *max)
 {
@@ -579,7 +627,9 @@ arv_camera_get_exposure_time_bounds (ArvCamera *camera, double *min, double *max
 			arv_device_get_float_feature_bounds (camera->priv->device, "ExposureTimeBaseAbs", min, max);
 			break;
 		case ARV_CAMERA_SERIES_BASLER_ACE:
-			arv_device_get_integer_feature_bounds (camera->priv->device, "ExposureTimeRaw", &int_min, &int_max);
+			arv_device_get_integer_feature_bounds (camera->priv->device, "ExposureTimeRaw",
+							       &int_min,
+							       &int_max);
 			if (min != NULL)
 				*min = int_min;
 			if (max != NULL)
@@ -591,6 +641,14 @@ arv_camera_get_exposure_time_bounds (ArvCamera *camera, double *min, double *max
 	}
 }
 
+/**
+ * arv_camera_set_exposure_time_auto:
+ * @camera: a #ArvCamera
+ * @auto_mode: auto exposure mode selection
+ *
+ * Configures automatic exposure feature.
+ **/
+
 void
 arv_camera_set_exposure_time_auto (ArvCamera *camera, ArvAuto auto_mode)
 {
@@ -599,6 +657,13 @@ arv_camera_set_exposure_time_auto (ArvCamera *camera, ArvAuto auto_mode)
 	arv_device_set_string_feature_value (camera->priv->device, "ExposureAuto", arv_auto_to_string (auto_mode));
 }
 
+/**
+ * arv_camera_get_exposure_time_auto:
+ * @camera: a #ArvCamera
+ *
+ * Returns: auto exposure mode selection
+ **/
+
 ArvAuto
 arv_camera_get_exposure_time_auto (ArvCamera *camera)
 {
@@ -631,7 +696,8 @@ arv_camera_set_gain (ArvCamera *camera, gint gain)
 /**
  * arv_camera_get_gain:
  * @camera: a #ArvCamera
- * Return value: the current gain setting.
+ *
+ * Returns: the current gain setting.
  */
 
 gint
@@ -642,6 +708,15 @@ arv_camera_get_gain (ArvCamera *camera)
 	return arv_device_get_integer_feature_value (camera->priv->device, "GainRaw");
 }
 
+/**
+ * arv_camera_get_gain_bounds:
+ * @camera: a #ArvCamera
+ * @min: (out): minimum gain
+ * @max: (out): maximum gain
+ *
+ * Retrieves gain bounds.
+ */
+
 void
 arv_camera_get_gain_bounds (ArvCamera *camera, gint *min, gint *max)
 {
@@ -657,6 +732,14 @@ arv_camera_get_gain_bounds (ArvCamera *camera, gint *min, gint *max)
 		*max = max64;
 }
 
+/**
+ * arv_camera_set_gain_auto:
+ * @camera: a #ArvCamera
+ * @auto_mode: auto gaine mode selection
+ *
+ * Configures automatic gain feature.
+ **/
+
 void
 arv_camera_set_gain_auto (ArvCamera *camera, ArvAuto auto_mode)
 {
@@ -665,6 +748,13 @@ arv_camera_set_gain_auto (ArvCamera *camera, ArvAuto auto_mode)
 	arv_device_set_string_feature_value (camera->priv->device, "GainAuto", arv_auto_to_string (auto_mode));
 }
 
+/**
+ * arv_camera_get_gain_auto:
+ * @camera: a #ArvCamera
+ *
+ * Returns: auto gain mode selection
+ **/
+
 ArvAuto
 arv_camera_get_gain_auto (ArvCamera *camera)
 {
@@ -678,10 +768,11 @@ arv_camera_get_gain_auto (ArvCamera *camera)
 /**
  * arv_camera_get_payload:
  * @camera: a #ArvCamera
- * Return value: the frame storage size, in bytes.
  * 
  * Retrieves the size needed for the storage of an image. This value is used
  * for the creation of the stream buffers.
+ *
+ * Returns: frame storage size, in bytes.
  */
 
 guint
@@ -695,9 +786,10 @@ arv_camera_get_payload (ArvCamera *camera)
 /**
  * arv_camera_get_device:
  * @camera: a #ArvCamera
- * Return value: the underlying device object.
  *
- * Retrieves the #ArvDevice object for more complete access to the camera features.
+ * Retrieves the #ArvDevice object for more complete access to camera features.
+ *
+ * Returns: (transfer none): underlying device object.
  */
 
 ArvDevice *
@@ -711,10 +803,11 @@ arv_camera_get_device (ArvCamera *camera)
 /**
  * arv_camera_new:
  * @name: (allow-none): name of the camera.
- * Return value: a new #ArvCamera.
  *
  * Creates a new #ArvCamera. If @name is null, it will instantiate the
- * first available camera
+ * first available camera.
+ *
+ * Returns: a new #ArvCamera.
  */
 
 ArvCamera *
