@@ -279,14 +279,28 @@ arv_gv_interface_receive_hello_packet (ArvGvInterface *gv_interface)
 }
 
 static void
-arv_gv_interface_update_device_list (ArvInterface *interface)
+arv_gv_interface_update_device_list (ArvInterface *interface, GArray *device_ids)
 {
-	arv_gv_interface_send_discover_packet (ARV_GV_INTERFACE (interface));
-	arv_gv_interface_receive_hello_packet (ARV_GV_INTERFACE (interface));
+	ArvGvInterface *gv_interface;
+	GHashTableIter iter;
+	gpointer key, value;
+
+	gv_interface = ARV_GV_INTERFACE (interface);
+
+	arv_gv_interface_send_discover_packet (gv_interface);
+	arv_gv_interface_receive_hello_packet (gv_interface);
+
+	g_array_set_size (device_ids, 0);
+
+	g_hash_table_iter_init (&iter, gv_interface->priv->devices);
+	while (g_hash_table_iter_next (&iter, &key, &value)) {
+		char *device_id = g_strdup (key);
+		g_array_append_val (device_ids, device_id);
+	}
 }
 
 static ArvDevice *
-arv_gv_interface_new_device (ArvInterface *interface, const char *name)
+arv_gv_interface_open_device (ArvInterface *interface, const char *device_id)
 {
 	ArvGvInterface *gv_interface;
 	ArvDevice *device = NULL;
@@ -295,14 +309,14 @@ arv_gv_interface_new_device (ArvInterface *interface, const char *name)
 
 	gv_interface = ARV_GV_INTERFACE (interface);
 
-	if (name == NULL) {
+	if (device_id == NULL) {
 		GList *device_list;
 
 		device_list = g_hash_table_get_values (gv_interface->priv->devices);
 		device_infos = device_list != NULL ? device_list->data : NULL;
 		g_list_free (device_list);
 	} else
-		device_infos = g_hash_table_lookup (gv_interface->priv->devices, name);
+		device_infos = g_hash_table_lookup (gv_interface->priv->devices, device_id);
 
 	if (device_infos == NULL)
 		return NULL;
@@ -315,24 +329,43 @@ arv_gv_interface_new_device (ArvInterface *interface, const char *name)
 	return device;
 }
 
+static ArvInterface *gv_interface = NULL;
+static GStaticMutex gv_interface_mutex = G_STATIC_MUTEX_INIT;
+
+/**
+ * arv_gv_interface_get_instance:
+ *
+ * Gets the unique instance of the GV interface.
+ *
+ * Returns: (transfer none): a #ArvInterface singleton.
+ */
+
 ArvInterface *
 arv_gv_interface_get_instance (void)
 {
-	static ArvInterface *gv_interface = NULL;
-	static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
-
-	g_static_mutex_lock (&mutex);
+	g_static_mutex_lock (&gv_interface_mutex);
 
 	if (gv_interface == NULL)
 		gv_interface = g_object_new (ARV_TYPE_GV_INTERFACE, NULL);
-	else
-		g_object_ref (gv_interface);
 
-	g_static_mutex_unlock (&mutex);
+	g_static_mutex_unlock (&gv_interface_mutex);
 
 	return ARV_INTERFACE (gv_interface);
 }
 
+void
+arv_gv_interface_destroy_instance (void)
+{
+	g_static_mutex_lock (&gv_interface_mutex);
+
+	if (gv_interface != NULL) {
+		g_object_unref (gv_interface);
+		gv_interface = NULL;
+	}
+
+	g_static_mutex_unlock (&gv_interface_mutex);
+}
+
 static void
 arv_gv_interface_init (ArvGvInterface *gv_interface)
 {
@@ -372,7 +405,7 @@ arv_gv_interface_class_init (ArvGvInterfaceClass *gv_interface_class)
 	object_class->finalize = arv_gv_interface_finalize;
 
 	interface_class->update_device_list = arv_gv_interface_update_device_list;
-	interface_class->new_device = arv_gv_interface_new_device;
+	interface_class->open_device = arv_gv_interface_open_device;
 }
 
 G_DEFINE_TYPE (ArvGvInterface, arv_gv_interface, ARV_TYPE_INTERFACE)
