@@ -49,7 +49,6 @@ enum {
 
 static GObjectClass *parent_class = NULL;
 
-
 struct _ArvStreamPrivate {
 	GAsyncQueue *input_queue;
 	GAsyncQueue *output_queue;
@@ -78,7 +77,7 @@ arv_stream_push_buffer (ArvStream *stream, ArvBuffer *buffer)
 /**
  * arv_stream_pop_buffer:
  * @stream: a #ArvStream
- * Returns: a #ArvBuffer
+ * Returns: (transfer full): a #ArvBuffer
  *
  * Pops a buffer from the output queue of @stream. The retrieved buffer
  * may contain an invalid image. Caller should check the buffer status before using it.
@@ -92,6 +91,36 @@ arv_stream_pop_buffer (ArvStream *stream)
 	return g_async_queue_try_pop (stream->priv->output_queue);
 }
 
+/**
+ * arv_stream_timed_pop_buffer:
+ * @stream: a #ArvStream
+ * @timeout: timeout, in µs
+ * Returns: (transfer full): a #ArvBuffer
+ *
+ * Pops a buffer from the output queue of @stream, waiting no more than @timeout. The retrieved buffer
+ * may contain an invalid image. Caller should check the buffer status before using it.
+ */
+
+ArvBuffer *
+arv_stream_timed_pop_buffer (ArvStream *stream, guint64 timeout)
+{
+	GTimeVal end_time;
+
+	g_return_val_if_fail (ARV_IS_STREAM (stream), NULL);
+
+	g_get_current_time (&end_time);
+	g_time_val_add (&end_time, timeout);
+
+	return g_async_queue_timed_pop (stream->priv->output_queue, &end_time);
+}
+
+/**
+ * arv_stream_pop_input_buffer: (skip)
+ * @stream: (transfer full): a #ArvStream
+ *
+ * Pos a buffer from the input queue of @stream.
+ */
+
 ArvBuffer *
 arv_stream_pop_input_buffer (ArvStream *stream)
 {
@@ -330,7 +359,6 @@ arv_stream_class_init (ArvStreamClass *node_class)
 				      "Emit signals", FALSE,
 				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)
 		);
-
 }
 
 G_DEFINE_ABSTRACT_TYPE (ArvStream, arv_stream, G_TYPE_OBJECT)
