@@ -77,6 +77,15 @@ _arv_statistic_free (ArvStatistic *statistic)
 	g_free (statistic);
 }
 
+/**
+ * arv_statistic_new: (skip)
+ * @n_histograms: number of histograms
+ * @n_bins: number of bins for each histogram
+ * @bin_step: bin step
+ * @offset: offset of the first bin
+ * Return value: a new #ArvStatistic structure
+ */
+
 ArvStatistic *
 arv_statistic_new (unsigned int n_histograms, unsigned n_bins, unsigned int bin_step, int offset)
 {
@@ -434,6 +443,32 @@ arv_value_copy (ArvValue *to, const ArvValue *from)
 	*to = *from;
 }
 
+ArvValue *
+arv_value_duplicate (const ArvValue *from)
+{
+	ArvValue *value = g_new (ArvValue, 1);
+
+	if (from == NULL)
+		return NULL;
+
+	*value = *from;
+
+	return value;
+}
+
+GType
+arv_value_get_type (void)
+{
+	GType type_id = 0;
+
+	if (type_id == 0)
+		type_id = g_boxed_type_register_static ("ArvValue",
+							(GBoxedCopyFunc) arv_value_duplicate,
+							(GBoxedFreeFunc) arv_value_free);
+
+	return type_id;
+}
+
 void
 arv_value_set_int64 (ArvValue *value, gint64 v_int64)
 {
@@ -480,8 +515,14 @@ arv_value_holds_double (ArvValue *value)
 
 /* GValue utilities */
 
+/**
+ * arv_create_int64_g_value:
+ * @v_int64: default 64 bit integer value
+ * Return value: (transfer full) a new GValue holding a gint64.
+ */
+
 GValue *
-arv_new_g_value_int64 (gint64 v_int64)
+arv_create_int64_g_value (gint64 v_int64)
 {
 	GValue *value = g_new0 (GValue, 1);
 
@@ -491,8 +532,14 @@ arv_new_g_value_int64 (gint64 v_int64)
 	return value;
 }
 
+/**
+ * arv_create_string_g_value:
+ * @v_string: default 64 bit integer value
+ * Return value: (transfer full) a new GValue holding a string.
+ */
+
 GValue *
-arv_new_g_value_string (const char *v_string)
+arv_create_string_g_value (const char *v_string)
 {
 	GValue *value = g_new0 (GValue, 1);
 
@@ -598,6 +645,14 @@ arv_copy_memory_with_endianess (void *to, size_t to_size, guint to_endianess,
 
 #define ARV_DECOMPRESS_CHUNK 16384
 
+/**
+ * arv_decompress:
+ * @input_buffer: compressed data
+ * @input_buffer: size of compressed data
+ * @output_size: (out): placeholder for inflated data
+ * Return value: (transfer full): a newly allocated buffer
+ **/
+
 void *
 arv_decompress (void *input_buffer, size_t input_size, size_t *output_size)
 {
@@ -688,3 +743,126 @@ CLEANUP:
 
 	return NULL;
 }
+
+/**
+ * SECTION: arvgst
+ * @short_description: Gstreamer utilities
+ */
+
+#define ARV_MAKE_FOURCC(a,b,c,d)        ((guint32)((a)|(b)<<8|(c)<<16|(d)<<24))
+
+typedef struct {
+	ArvPixelFormat pixel_format;
+	const char *gst_caps_string;
+	const char *name;
+	int bpp;
+	int depth;
+	guint32 fourcc;
+} ArvGstCapsInfos;
+
+ArvGstCapsInfos arv_gst_caps_infos[] = {
+	{
+		ARV_PIXEL_FORMAT_MONO_8,
+		"video/x-raw-gray, bpp=(int)8, depth=(int)8",
+		"video/x-raw-gray", 	8,	8,	0
+	},
+	{
+		ARV_PIXEL_FORMAT_MONO_10,
+		"video/x-raw-gray, bpp=(int)16, depth=(int)10",
+		"video/x-raw-gray", 	16,	10,	0,
+	},
+	{
+	       ARV_PIXEL_FORMAT_MONO_12,
+	       "video/x-raw-gray, bpp=(int)16, depth=(int)12",
+	       "video/x-raw-gray",	16,	12,	0,
+	},
+	{
+		ARV_PIXEL_FORMAT_MONO_12_PACKED,
+		"video/x-raw-gray, bpp=(int)12, depth=(int)12",
+		"video/x-raw-gray",	12,	12,	0,
+	},
+	{
+		ARV_PIXEL_FORMAT_MONO_16,
+		"video/x-raw-gray, bpp=(int)16, depth=(int)16",
+		"video/x-raw-gray",	16,	16,	0
+	},
+	{
+	       ARV_PIXEL_FORMAT_BAYER_BG_8,
+	       "video/x-raw-bayer, bpp=(int)8, depth=(int)8",
+	       "video/x-raw-bayer",	8,	8,	0
+	},
+	{
+		ARV_PIXEL_FORMAT_YUV_422_PACKED,
+		"video/x-raw-yuv, format=(fourcc)UYVY",
+		"video/x-raw-yuv",	0,	0,	ARV_MAKE_FOURCC ('U','Y','V','Y')
+	},
+	{
+	       ARV_PIXEL_FORMAT_YUV_422_YUYV_PACKED,
+	       "video/x-raw-yuv, format=(fourcc)YUY2",
+	       "video/x-raw-yuv",	0,	0,	ARV_MAKE_FOURCC ('Y','U','Y','2')
+	},
+	{
+		ARV_PIXEL_FORMAT_RGB_8_PACKED,
+		"video/x-raw-rgb, bpp=(int)24, depth=(int)24",
+		"video/x-raw-rgb",	24,	24,	0
+	},
+	{
+		ARV_PIXEL_FORMAT_CUSTOM_YUV_422_YUYV_PACKED,
+		"video/x-raw-yuv, format=(fourcc)YUY2",
+		"video/x-raw-yuv",	0,	0,	ARV_MAKE_FOURCC ('Y','U','Y','2')
+	},
+	{
+		ARV_PIXEL_FORMAT_CUSTOM_BAYER_BG_16,
+		"video/x-raw-bayer, bpp=(int)16, depth=(int)16",
+		"video/x-raw-bayer",	16,	16,	0
+	}
+};
+
+/**
+ * arv_pixel_format_to_gst_caps_string:
+ * @pixel_format: a pixel format
+ * Return value: a gstreamer caps string describing the given @pixel_format.
+ */
+
+const char *
+arv_pixel_format_to_gst_caps_string (ArvPixelFormat pixel_format)
+{
+	int i;
+
+	for (i = 0; i < G_N_ELEMENTS (arv_gst_caps_infos); i++)
+		if (arv_gst_caps_infos[i].pixel_format == pixel_format)
+			break;
+
+	if (i == G_N_ELEMENTS (arv_gst_caps_infos)) {
+		arv_debug ("gst", "[PixelFormat::to_gst_caps_string] 0x%08x not found", pixel_format);
+		return NULL;
+	}
+
+	arv_debug ("gst", "[PixelFormat::to_gst_caps_string] 0x%08x -> %s",
+		   pixel_format, arv_gst_caps_infos[i].gst_caps_string);
+
+	return arv_gst_caps_infos[i].gst_caps_string;
+}
+
+ArvPixelFormat
+arv_pixel_format_from_gst_caps (const char *name, int bpp, int depth, guint32 fourcc)
+{
+	unsigned int i;
+
+	g_return_val_if_fail (name != NULL, 0);
+
+	for (i = 0; i < G_N_ELEMENTS (arv_gst_caps_infos); i++) {
+		if (strcmp (name, arv_gst_caps_infos[i].name) != 0)
+			continue;
+
+		if (strcmp (name, "video/x-raw-yuv") == 0 &&
+		    fourcc == arv_gst_caps_infos[i].fourcc)
+			return arv_gst_caps_infos[i].pixel_format;
+
+		if (depth == arv_gst_caps_infos[i].depth &&
+		    bpp == arv_gst_caps_infos[i].bpp)
+			return arv_gst_caps_infos[i].pixel_format;
+	}
+
+	return 0;
+}
