@@ -29,6 +29,12 @@
 #include <stdlib.h>
 #include <math.h>
 
+static char *arv_viewer_option_debug_domains = NULL;
+static gboolean arv_viewer_option_auto_socket_buffer = FALSE;
+static gboolean arv_viewer_option_no_packet_resend = FALSE;
+static unsigned int arv_viewer_option_packet_timeout = 20;
+static unsigned int arv_viewer_option_frame_retention = 100;
+
 typedef struct {
 	ArvCamera *camera;
 	ArvDevice *device;
@@ -361,9 +367,24 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	g_free (camera_id);
 
 	viewer->stream = arv_camera_create_stream (viewer->camera, NULL, NULL);
+	if (ARV_IS_GV_STREAM (viewer->stream)) {
+		if (arv_viewer_option_auto_socket_buffer)
+			g_object_set (viewer->stream,
+				      "socket-buffer", ARV_GV_STREAM_SOCKET_BUFFER_AUTO,
+				      "socket-buffer-size", 0,
+				      NULL);
+		if (arv_viewer_option_no_packet_resend)
+			g_object_set (viewer->stream,
+				      "packet-resend", ARV_GV_STREAM_PACKET_RESEND_NEVER,
+				      NULL);
+		g_object_set (viewer->stream,
+			      "packet-timeout", (unsigned) arv_viewer_option_packet_timeout * 1000,
+			      "frame-retention", (unsigned) arv_viewer_option_frame_retention * 1000,
+			      NULL);
+	}
 	arv_stream_set_emit_signals (viewer->stream, TRUE);
 	payload = arv_camera_get_payload (viewer->camera);
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < 50; i++)
 		arv_stream_push_buffer (viewer->stream, arv_buffer_new (payload, NULL));
 
 	arv_camera_get_region (viewer->camera, NULL, NULL, &width, &height);
@@ -528,14 +549,58 @@ arv_viewer_new (void)
 	return viewer;
 }
 
+static const GOptionEntry arv_viewer_option_entries[] =
+{
+	{
+		"auto-buffer-size",			'a', 0, G_OPTION_ARG_NONE,
+		&arv_viewer_option_auto_socket_buffer,	"Auto socket buffer size", NULL
+	},
+	{
+		"no-packet-resend",			'r', 0, G_OPTION_ARG_NONE,
+		&arv_viewer_option_no_packet_resend,	"No packet resend", NULL
+	},
+	{
+		"packet-timeout", 			'p', 0, G_OPTION_ARG_INT,
+		&arv_viewer_option_packet_timeout, 	"Packet timeout (ms)", NULL
+	},
+	{
+		"frame-retention", 			'm', 0, G_OPTION_ARG_INT,
+		&arv_viewer_option_frame_retention, 	"Frame retention (ms)", NULL
+	},
+	{
+		"debug", 				'd', 0, G_OPTION_ARG_STRING,
+		&arv_viewer_option_debug_domains, 	"Debug domains", NULL
+	},
+	{ NULL }
+};
+
 int
 main (int argc,char *argv[])
 {
 	ArvViewer *viewer;
+	GOptionContext *context;
+	GError *error = NULL;
+
+	g_thread_init (NULL);
+
+	context = g_option_context_new (NULL);
+	g_option_context_add_main_entries (context, arv_viewer_option_entries, NULL);
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
+	g_option_context_add_group (context, gst_init_get_option_group ());
+	if (!g_option_context_parse (context, &argc, &argv, &error)) {
+		g_option_context_free (context);
+		g_print ("Option parsing failed: %s\n", error->message);
+		g_error_free (error);
+		return EXIT_FAILURE;
+	}
+
+	g_option_context_free (context);
 
 	gtk_init (&argc, &argv);
 	gst_init (&argc, &argv);
 
+	arv_debug_enable (arv_viewer_option_debug_domains);
+
 	viewer = arv_viewer_new ();
 
 	arv_viewer_update_device_list_cb (viewer);
@@ -543,5 +608,8 @@ main (int argc,char *argv[])
 
 	gtk_main ();
 
+	/* For debug purpose only */
+	arv_shutdown ();
+
 	return EXIT_SUCCESS;
 }
